<?xml version="1.0" ?><!DOCTYPE TS><TS language="ru" version="2.0">
<defaultcodec>UTF-8</defaultcodec>
<context>
    <name>AboutView</name>
    <message>
        <source>Version %1</source>
        <translation>Версия %1</translation>
    </message>
    <message>
        <source>%1 is Free Software but its development takes precious time.</source>
        <translation>%1 свободное программное обеспечение, но ее развитие занимает драгоценное время.</translation>
    </message>
    <message>
        <source>Please &lt;a href=&apos;%1&apos;&gt;donate&lt;/a&gt; to support the continued development of %2.</source>
        <translation>Пожалуйста, &lt;a href=&apos;%1&apos;&gt;пожертвуйте&lt;/a&gt; для поддержки дальнейшего развития %2.</translation>
    </message>
    <message>
        <source>Released under the &lt;a href=&apos;%1&apos;&gt;GNU General Public License&lt;/a&gt;</source>
        <translation>Выпущено под &lt;a href=&apos;%1&apos;&gt;лицензией GNU General Public License&lt;/a&gt;</translation>
    </message>
    <message>
        <source>&amp;Close</source>
        <translation>&amp;Закрыть</translation>
    </message>
    <message>
        <source>About</source>
        <translation>О программе</translation>
    </message>
    <message>
        <source>What you always wanted to know about %1 and never dared to ask</source>
        <translation>То, что вы всегда хотели знать о %1 и никогда не осмелились спросить</translation>
    </message>
    <message>
        <source>You may want to try my other apps as well:</source>
        <translation>Вы также можете попробовать другие мои приложения:</translation>
    </message>
    <message>
        <source>%1, a YouTube app</source>
        <translation>%1, приложение YouTube</translation>
    </message>
    <message>
        <source>%1, a YouTube music player</source>
        <translation>%1, музыкальный плеер для YouTube</translation>
    </message>
    <message>
        <source>Translate %1 to your native language using %2</source>
        <translation>Перевести %1 на ваш родной язык с помощью %2</translation>
    </message>
</context>
<context>
    <name>AlbumInfo</name>
    <message>
        <source>Buy on %1</source>
        <translation>Купить в %1</translation>
    </message>
    <message>
        <source>Read more</source>
        <translation>Читать подробнее</translation>
    </message>
</context>
<context>
    <name>ArtistInfo</name>
    <message>
        <source>Read more</source>
        <translation>Читать подробнее</translation>
    </message>
</context>
<context>
    <name>BreadcrumbWidget</name>
    <message>
        <source>&amp;Back</source>
        <translation>&amp;Назад</translation>
    </message>
    <message>
        <source>Go back</source>
        <translation>Вернуться назад</translation>
    </message>
</context>
<context>
    <name>ChooseFolderView</name>
    <message>
        <source>Welcome to &lt;a href=&apos;%1&apos;&gt;%2&lt;/a&gt;,</source>
        <translation>Добро пожаловать на &lt;a href=&apos;%1&apos;&gt;%2&lt;/a&gt;,</translation>
    </message>
    <message>
        <source>%1 needs to scan your music collection.</source>
        <translation>%1 должен просмотреть вашу музыкальную коллекцию.</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Отмена</translation>
    </message>
    <message>
        <source>Use iTunes collection</source>
        <translation>Использовать коллекцию ITunes</translation>
    </message>
    <message>
        <source>Use %1</source>
        <translation>Использовать %1</translation>
    </message>
    <message>
        <source>Choose a folder...</source>
        <translation>Выберите папку...</translation>
    </message>
    <message>
        <source>%1 will connect to the Last.fm web services and pass artist names and album titles in order to fetch covert art, biographies and much more.</source>
        <translation>%1 будет подключаться к службам Last.fm и на основании названий композиций получать обложки альбомов, биографии исполнителей и многое другое.</translation>
    </message>
    <message>
        <source>If you have privacy concerns about this you can quit now.</source>
        <translation>Если у вас есть проблемы с конфиденциальностью, то можете выйти из программы прямо сейчас.</translation>
    </message>
    <message>
        <source>Where&apos;s your music collection?</source>
        <translation>Где ваша музыкальная коллекция?</translation>
    </message>
    <message>
        <source>Select the location of your music collection.</source>
        <translation>Выберите расположение вашей музыкальной коллекции.</translation>
    </message>
    <message>
        <source>Locate your collection</source>
        <translation>Найдите вашу коллекцию</translation>
    </message>
</context>
<context>
    <name>ClearButton</name>
    <message>
        <source>Clear</source>
        <translation>Очистить</translation>
    </message>
</context>
<context>
    <name>CollectionScanner</name>
    <message>
        <source>A scanning task is already running</source>
        <translation>Процесс сканирования уже запущен</translation>
    </message>
</context>
<context>
    <name>CollectionScannerView</name>
    <message>
        <source>%1 is scanning your music collection.</source>
        <translation>%1 сканирует вашу музыкальную коллекцию.</translation>
    </message>
    <message>
        <source>%1 is using &lt;a href=&apos;%2&apos;&gt;%3&lt;/a&gt; to catalog your music.</source>
        <translation>%1 использует &lt;a href=&apos;%2&apos;&gt;%3&lt;/a&gt; для каталогизации вашей музыки.</translation>
    </message>
    <message>
        <source>This will take time depending on your collection size and network speed.</source>
        <translation>Это займет некоторое время, в зависимости от размера вашей коллекции и скорости соединения.</translation>
    </message>
    <message>
        <source>Go grab a coffee</source>
        <translation>Можете пока выпить кофе</translation>
    </message>
</context>
<context>
    <name>DemoStartupView</name>
    <message>
        <source>Please license %1</source>
        <translation>	
Лицензия %1</translation>
    </message>
    <message>
        <source>This demo has expired.</source>
        <translation>Демонстрационный период истек.</translation>
    </message>
    <message>
        <source>This demo will expire in %1 days.</source>
        <translation>Демонстрационный период истекает через %1 дн.</translation>
    </message>
    <message>
        <source>By purchasing the full version, you will also support the hard work I put into creating %1.</source>
        <translation>При покупке полной версии, вы также оказываете поддержку тяжелой работы в создании %1.</translation>
    </message>
    <message>
        <source>Use Demo</source>
        <translation>Демонстрация</translation>
    </message>
    <message>
        <source>Get the full version</source>
        <translation>Получить полную версию</translation>
    </message>
    <message>
        <source>The full version allows you to add more than %1 tracks to the playlist and listen to your music without interruptions.</source>
        <translation>Полная версия позволяет добавлять более %1 треков в плейлист и слушать музыку без перерывов.</translation>
    </message>
</context>
<context>
    <name>DropArea</name>
    <message>
        <source>Drop here to append to the playlist</source>
        <translation>Перетащите сюда, чтобы добавить в список воспроизведения</translation>
    </message>
</context>
<context>
    <name>FinderWidget</name>
    <message>
        <source>Artists</source>
        <translation>Исполнители</translation>
    </message>
    <message>
        <source>Albums</source>
        <translation>Альбомы</translation>
    </message>
    <message>
        <source>Folders</source>
        <translation>Папки</translation>
    </message>
</context>
<context>
    <name>GlobalShortcuts</name>
    <message>
        <source>Play</source>
        <translation>Воспроизвести</translation>
    </message>
    <message>
        <source>Pause</source>
        <translation>Пауза</translation>
    </message>
    <message>
        <source>Play/Pause</source>
        <translation>Воспроизведение/Пауза</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation>Остановить</translation>
    </message>
    <message>
        <source>Stop playing after current track</source>
        <translation>Остановить воспроизведение после текущего трека</translation>
    </message>
    <message>
        <source>Next track</source>
        <translation>Следующий трек</translation>
    </message>
    <message>
        <source>Previous track</source>
        <translation>Предыдущий трек</translation>
    </message>
    <message>
        <source>Increase volume</source>
        <translation>Увеличение громкости</translation>
    </message>
    <message>
        <source>Decrease volume</source>
        <translation>Уменьшение громкости</translation>
    </message>
    <message>
        <source>Mute</source>
        <translation>Отключить звук</translation>
    </message>
    <message>
        <source>Seek forward</source>
        <translation>Перемотать вперед</translation>
    </message>
    <message>
        <source>Seek backward</source>
        <translation>Перемотать назад</translation>
    </message>
</context>
<context>
    <name>LastFm</name>
    <message>
        <source>Authentication failed</source>
        <translation>Ошибка аутентификации</translation>
    </message>
</context>
<context>
    <name>LastFmLoginDialog</name>
    <message>
        <source>Log in to %1</source>
        <translation>Войти на %1</translation>
    </message>
    <message>
        <source>&amp;Username:</source>
        <translation>&amp;Имя пользователя:</translation>
    </message>
    <message>
        <source>&amp;Password:</source>
        <translation>&amp;Пароль:</translation>
    </message>
    <message>
        <source>Signup for a %1 account</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Forgot your &lt;a href=&apos;%1&apos;&gt;username&lt;/a&gt; or &lt;a href=&apos;%2&apos;&gt;password&lt;/a&gt;?</source>
        <translation>Забыли свой &lt;a href=&apos;%1&apos;&gt;логин&lt;/a&gt; или &lt;a href=&apos;%2&apos;&gt;пароль&lt;/a&gt;?</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>&amp;Back</source>
        <translation>&amp;Назад</translation>
    </message>
    <message>
        <source>Go to the previous view</source>
        <translation>Перейти на предыдущий экран</translation>
    </message>
    <message>
        <source>&amp;Info</source>
        <translation>&amp;Информация</translation>
    </message>
    <message>
        <source>Show information about the current track</source>
        <translation>Показать информацию о текущей композиции</translation>
    </message>
    <message>
        <source>P&amp;revious</source>
        <translation>Пр&amp;едыдущий</translation>
    </message>
    <message>
        <source>Go back to the previous track</source>
        <translation>Вернуться к предыдущему треку</translation>
    </message>
    <message>
        <source>&amp;Next</source>
        <translation>С&amp;ледующий</translation>
    </message>
    <message>
        <source>Skip to the next track</source>
        <translation>Перейти к следующему треку</translation>
    </message>
    <message>
        <source>&amp;Play</source>
        <translation>Воспр&amp;оизведение</translation>
    </message>
    <message>
        <source>Start playback</source>
        <translation>Начать воспроизведение</translation>
    </message>
    <message>
        <source>&amp;Full Screen</source>
        <translation>Полный &amp;экран</translation>
    </message>
    <message>
        <source>Go full screen</source>
        <translation>Перейти на полный экран</translation>
    </message>
    <message>
        <source>&amp;Remove</source>
        <translation>&amp;Удалить</translation>
    </message>
    <message>
        <source>Remove the selected tracks from the playlist</source>
        <translation>Удалить выбранные треки из плейлиста</translation>
    </message>
    <message>
        <source>Move &amp;Up</source>
        <translation>Переместить &amp;вверх</translation>
    </message>
    <message>
        <source>Move up the selected tracks in the playlist</source>
        <translation>Переместить вверх выбранные треки в плейлисте</translation>
    </message>
    <message>
        <source>Move &amp;Down</source>
        <translation>Переместить вни&amp;з</translation>
    </message>
    <message>
        <source>Move down the selected tracks in the playlist</source>
        <translation>Переместить вниз выбранные треки в плейлисте</translation>
    </message>
    <message>
        <source>&amp;Quit</source>
        <translation>Выйт&amp;и</translation>
    </message>
    <message>
        <source>Bye</source>
        <translation>Пока</translation>
    </message>
    <message>
        <source>&amp;Change collection folder...</source>
        <translation>&amp;Сменить каталог с музыкой...</translation>
    </message>
    <message>
        <source>Choose a different music collection folder</source>
        <translation>Выберите другую папку коллекции музыки</translation>
    </message>
    <message>
        <source>&amp;Website</source>
        <translation>&amp;Веб-сайт</translation>
    </message>
    <message>
        <source>%1 on the Web</source>
        <translation>%1 в Интернете</translation>
    </message>
    <message>
        <source>Make a &amp;donation</source>
        <translation>Сделать по&amp;жертвование</translation>
    </message>
    <message>
        <source>Please support the continued development of %1</source>
        <translation>Пожалуйста, поддержите дальнейшее развитие %1</translation>
    </message>
    <message>
        <source>&amp;About</source>
        <translation>&amp;О программе</translation>
    </message>
    <message>
        <source>Info about %1</source>
        <translation>Информация о %1</translation>
    </message>
    <message>
        <source>&amp;Clear</source>
        <translation>О&amp;чистить</translation>
    </message>
    <message>
        <source>Remove all tracks from the playlist</source>
        <translation>Удалить все треки из плейлиста</translation>
    </message>
    <message>
        <source>&amp;Shuffle</source>
        <translation>&amp;Случайно</translation>
    </message>
    <message>
        <source>Random playlist mode</source>
        <translation>Играть в случайном порядке</translation>
    </message>
    <message>
        <source>&amp;Repeat</source>
        <translation>Повт&amp;орять</translation>
    </message>
    <message>
        <source>Play first song again after all songs are played</source>
        <translation>Играть плейлист сначала после последней песни</translation>
    </message>
    <message>
        <source>Mute volume</source>
        <translation>Выключить звук</translation>
    </message>
    <message>
        <source>&amp;Application</source>
        <translation>При&amp;ложение</translation>
    </message>
    <message>
        <source>&amp;Playback</source>
        <translation>Во&amp;спроизведение</translation>
    </message>
    <message>
        <source>Play&amp;list</source>
        <translation>Списо&amp;к</translation>
    </message>
    <message>
        <source>&amp;View</source>
        <translation>&amp;Вид</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation>Спр&amp;авка</translation>
    </message>
    <message>
        <source>Press %1 to raise the volume, %2 to lower it</source>
        <translation>Нажмите %1 чтобы увеличить громкость, %2 чтобы уменьшить</translation>
    </message>
    <message>
        <source>Opening %1</source>
        <translation>Открытие %1</translation>
    </message>
    <message>
        <source>Updating collection...</source>
        <translation>Обновление коллекции...</translation>
    </message>
    <message>
        <source>Updating collection - %1%</source>
        <translation>Обновление коллекции - %1%</translation>
    </message>
    <message>
        <source>Collection updated</source>
        <translation>Коллекция обновлена</translation>
    </message>
    <message>
        <source>Fatal error: %1</source>
        <translation>Фатальная ошибка: %1</translation>
    </message>
    <message>
        <source>Error: %1</source>
        <translation>Ошибка: %1</translation>
    </message>
    <message>
        <source>Leave &amp;Full Screen</source>
        <translation>Выйти из полноэкр&amp;анного режима</translation>
    </message>
    <message>
        <source>Remaining time: %1</source>
        <translation>Оставшееся время: %1</translation>
    </message>
    <message>
        <source>Volume at %1%</source>
        <translation>Громкость %1%</translation>
    </message>
    <message>
        <source>Volume is muted</source>
        <translation>Звук выключен</translation>
    </message>
    <message>
        <source>Volume is unmuted</source>
        <translation>Звук включен</translation>
    </message>
    <message>
        <source>Get the full version</source>
        <translation>Получить полную версию</translation>
    </message>
    <message>
        <source>%1 version %2 is now available.</source>
        <translation>%1 версия %2 уже доступна.</translation>
    </message>
    <message>
        <source>Remind me later</source>
        <translation>Напомнить позже</translation>
    </message>
    <message>
        <source>To get the updated version, download %1 again from the link you received via email and reinstall.</source>
        <translation>Чтобы получить обновленную версию, скачайте %1 ещё раз по ссылке, которую вы получили по электронной почте и переустановите программу.</translation>
    </message>
    <message>
        <source>Update</source>
        <translation>Обновление</translation>
    </message>
    <message>
        <source>&amp;Window</source>
        <translation>&amp;Окно</translation>
    </message>
    <message>
        <source>&amp;Minimize</source>
        <translation>&amp;Свернуть</translation>
    </message>
    <message>
        <source>&amp;Close</source>
        <translation>&amp;Закрыть</translation>
    </message>
    <message>
        <source>Buy %1...</source>
        <translation>Купить %1...</translation>
    </message>
    <message>
        <source>&amp;Stop After This Track</source>
        <translation>Ост&amp;ановить после текущего трека</translation>
    </message>
    <message>
        <source>&amp;Scrobbling</source>
        <translation>&amp;Скробблинг</translation>
    </message>
    <message>
        <source>Send played tracks titles to %1</source>
        <translation>Отправлять называния воспроизведенных треков на %1</translation>
    </message>
    <message>
        <source>&amp;Log Out from %1</source>
        <translation>&amp;Выйти из %1</translation>
    </message>
</context>
<context>
    <name>MediaView</name>
    <message>
        <source>Drop items here</source>
        <translation>Перетащите элементы сюда</translation>
    </message>
    <message>
        <source>Playlist finished</source>
        <translation>Плейлист завершен</translation>
    </message>
    <message>
        <source>This is just the demo version of %1.</source>
        <translation>Это всего лишь демо-версия %1.</translation>
    </message>
    <message>
        <source>It allows you to play a few tracks so you can test the application and see if it works for you.</source>
        <translation>Это позволяет вам прослушать несколько треков для того, чтобы вы могли проверить приложение на работоспособность.</translation>
    </message>
    <message>
        <source>Continue</source>
        <translation>Продолжить</translation>
    </message>
    <message>
        <source>Get the full version</source>
        <translation>Получить полную версию</translation>
    </message>
</context>
<context>
    <name>PlaylistModel</name>
    <message>
        <source>This demo is limited to only %1 tracks in the playlist.</source>
        <translation>Демонстрационный режим ограничивается только %1 треками в плейлисте.</translation>
    </message>
</context>
<context>
    <name>PlaylistView</name>
    <message>
        <source>Playlist is empty</source>
        <translation>Плейлист пуст</translation>
    </message>
    <message>
        <source>%1 tracks - Total length is %2</source>
        <translation>%1 треков - Общая продолжительность %2</translation>
    </message>
</context>
<context>
    <name>SearchLineEdit</name>
    <message>
        <source>Search</source>
        <translation>Поиск</translation>
    </message>
</context>
<context>
    <name>SearchView</name>
    <message>
        <source>Your search had no results.</source>
        <translation>По Вашему поисковому запросу нет никаких результатов.</translation>
    </message>
</context>
<context>
    <name>TrackListView</name>
    <message>
        <source>Tracks</source>
        <translation>Треки</translation>
    </message>
</context>
</TS>